globals [
  lastyear  ;; these variables are used to calculate herd growth by comparing this year's with last year's herd size
  thisyear

  a ;; these are variables used to set up herd composition when herds are initiated
  b
  c
  d
  ee
  f
  g
  total%

  oldsize  ;; to keep track of herd growth
  newsize  ;; to keep track of herd growth
  annualgrowthrate ;; growth rate from one year to the next
  growthlist ;; growth rate over the run of the model
  growthlistaverage ;; growth rate average over the run of the model
  startingpop ;; starting population at the beginning of the simulation
  endingpop ;; ending population at the end of each tick
  plotendingpop ;; plot of herd size over time in the interface

  season? ;; there are two seasons - animals reproduce in the rainy season - and die and are sold in the dry season

  global-num-cow  ;; these are variables to keep track of the number of animals in each age and sex class
  global-num-bull
  global-num-heifer
  global-num-bullock
  global-num-calf
  global-num-mcalf
  global-num-elderlycow
  global-num-whole-herd
  ]

breed [herds herd]
herds-own [
  num-0yom  ;; percentage of male calves age 0- 1 year in the herd
  num-0yof  ;; percentage of female calves age 0 - 1 year in the herd
  num-1yom
  num-1yof
  num-2yom
  num-2yof
  num-3yom
  num-3yof
  num-4yom
  num-4yof
  num-5yom
  num-5yof
  num-6yom
  num-6yof
  num-7yom
  num-7yof
  num-8yom
  num-8yof
  num-9yom
  num-9yof
  num-10yom
  num-10yof
  num-11yof
  num-12yof
  num-13yof
  num-14yof

  num-mcalf  ;; number of male calves in the herd
  num-calf   ;; number of female calves in the herd
  num-heifer
  num-bullock
  num-cow
  num-bull
  num-elderlycow
  total-herd-size  ;; total number of animals in the herd

  num-calf%  ;; percentage of female calves in the herd - this variable is used for herd composition in the initialization
  num-mcalf%
  num-heifer%
  num-bullock%
  num-cow%
  num-bull%
  num-elderlycow%
]

to setup
  ca  ;; clear all to start a new simulations
  set-default-shape herds "cow"
  set season?  "rainy" ;; model begins in the rainy season
  set oldsize 1 ;; calculating initial herd size
  set newsize 1 ;; calculating herd size at each tick
  set growthlist [] ;; this list is used to calculate herd growth over time

  create-herds 1  [ set size 3 ]

  ask herds [
  set total-herd-size initial-herd-size ;; intitializes herds with a normal distribution of age and sex classes

  set num-calf% (random-normal 10.06 2.54)
  set num-heifer% (random-normal 20.6 6.18)
  set num-cow% (random-normal 34.49 8.45)
  set num-elderlycow% (random-normal 2.61 0.46)
  set num-mcalf%  (random-normal 8.95 2.76)
  set num-bullock% (random-normal 14.73 5.64)
  set num-bull% (random-normal 4.04 3.11)

  set total% (num-calf% + num-heifer% + num-cow% + num-elderlycow% + num-mcalf% + num-bullock% + num-bull%) ;; ratchet for building the initial herd composition
  set a (num-calf%) / total%
  set b (num-calf% + num-heifer%) / total%
  set c (num-calf% + num-heifer% + num-cow% ) / total%
  set d (num-calf% + num-heifer% + num-cow% + num-elderlycow%) / total%
  set ee (num-calf% + num-heifer% + num-cow% + num-elderlycow% + num-mcalf% ) / total%
  set f (num-calf% + num-heifer% + num-cow% + num-elderlycow% + num-mcalf% + num-bullock% ) / total%
  set g (num-calf% + num-heifer% + num-cow% + num-elderlycow% + num-mcalf% + num-bullock% + num-bull%) / total%

  repeat total-herd-size [
    let picker random-float 1
    if picker < a  and  picker >= 0 [
      let subpicker one-of [0 1]
      if subpicker = 0 [set num-0yof num-0yof + 1]
      if subpicker = 1 [set num-1yof num-1yof + 1]
      ]
    if picker < b and  picker >= a [
      let subpicker one-of [2 3]
      if subpicker =  2 [set num-2yof num-2yof + 1]
      if subpicker = 3 [set num-3yof num-3yof + 1]
      ]
    if picker < c and  picker >= b [
      let subpicker one-of [4 5 6 7 8 9 10 11]
      if subpicker = 4 [set num-4yof num-4yof + 1]
      if subpicker = 5 [set num-5yof num-5yof + 1]
      if subpicker = 6 [set num-6yof num-6yof + 1]
      if subpicker = 7 [set num-7yof num-7yof + 1]
      if subpicker = 8 [set num-8yof num-8yof + 1]
      if subpicker = 9 [set num-9yof num-9yof + 1]
      if subpicker = 10 [set num-10yof num-10yof + 1]
      if subpicker = 11 [set num-11yof num-11yof + 1]
      ]
    if picker < d and  picker >= c [
      let subpicker one-of [12 13 14]
      if subpicker = 12 [set num-12yof num-12yof + 1]
      if subpicker = 13 [set num-13yof num-13yof + 1]
      if subpicker = 14 [set num-14yof num-14yof + 1]
      ]
    if picker < ee and  picker >= d [
      let subpicker one-of [0 1]
      if subpicker = 0 [set num-0yom num-0yom + 1]
      if subpicker = 1 [set num-1yom num-1yom + 1]
      ]
    if picker < f and  picker >= ee [
      let subpicker one-of [ 2 3 ]
      if subpicker = 2 [set num-2yom num-2yom + 1]
      if subpicker = 3 [set num-3yom num-3yom + 1]
      ]
    if picker < 1 and  picker >= f [
      let subpicker one-of [4 5 6 7 8 9 10]
      if subpicker = 4 [set num-4yom num-4yom + 1]
      if subpicker = 5 [set num-5yom num-5yom + 1]
      if subpicker = 6 [set num-6yom num-6yom + 1]
      if subpicker = 7 [set num-7yom num-7yom + 1]
      if subpicker = 8 [set num-8yom num-8yom + 1]
      if subpicker = 9 [set num-9yom num-9yom + 1]
      if subpicker = 10 [set num-10yom num-10yom + 1]
      ]
    ]]

ask herds [
  defineherds]
  globalcount ;; count of cattle for calculating growth rates

  ask herds [
     set startingpop  (num-calf + num-mcalf + num-heifer + num-bullock + num-cow + num-bull + num-elderlycow )
     set thisyear     (num-calf + num-mcalf + num-heifer + num-bullock + num-cow + num-bull + num-elderlycow )
     set lastyear thisyear
     ]
reset-ticks
end


to go  ;; this block of codes updates offtake, mortality, reproduction, and aging of animals in the herd
  if not any? turtles [ stop ];; if there are no animals in the herd, the herd "dies" and the simulation stops
    season-check;; checks whether it is  the rainy or dry season - cows reproduce in the rainy season and die and are sold in the dry season
    ask herds [
    defineherds ;; updates the number of animals in the different age and sex classes
    ifelse offtake [sellcattle][] ;; animals are sold in the dry season - this function can be turned on and off in the interface
    mortcattle  ;; sets mortality rates for different age and sex classes
    ageclasses  ;; animals age one year in the rainy season
    reproducecattle ;; cows reproduce
    ]
    globalcount

  tick ;; new season starts - two seasons is equal to one year

  if season? = "rainy" ;; annually the growth of herds are compared to the previous year in order to calculate a growth rate
     [
     ask herds [
     set lastyear thisyear
     set thisyear num-calf + num-mcalf + num-heifer + num-bullock + num-cow + num-bull + num-elderlycow]
     set growthlist lput (thisyear / lastyear) growthlist
     set growthlistaverage mean growthlist
     ]

  set endingpop 0 ;; this block of code updates number of animals in herd after death, offtake, aging, and reproduction
    ask herds [set endingpop endingpop + num-calf + num-mcalf + num-heifer + num-bullock + num-cow + num-bull + num-elderlycow]
    if season? = "rainy" [ask herds [
    set oldsize newsize
    set newsize (num-calf + num-mcalf + num-heifer + num-bullock + num-cow + num-bull + num-elderlycow )]
    if oldsize != 0 [ set annualgrowthrate (newsize / oldsize )]
     ]
   if endingpop <= 0 [stop]  ;; this block of code checks whether there are any animals left the in herd
   ask herds [if endingpop = 0 [die]] ;; the simulation ends when there are no more animals in the herd
end


to defineherds ;; this procedure is repeated throughout the model run to ensure the age and sex classes are updated after death, offtake, aging, and reproduction
 set num-mcalf (num-0yom + num-1yom)
 set num-calf (num-0yof + num-1yof)
 set num-heifer (num-2yof + num-3yof)
 set num-bullock (num-2yom + num-3yom )
 set num-cow (num-4yof + num-5yof + num-6yof + num-7yof + num-8yof + num-9yof + num-10yof + num-11yof)
 set num-bull (num-4yom + num-5yom + num-6yom + num-7yom + num-8yom + num-9yom + num-10yom)
 set num-elderlycow (num-12yof + num-13yof + num-14yof)
end


to season-check ;; determines the season
  ifelse (remainder ticks 2 = 0)
  [set season? "dry"]
  [set season? "rainy"]
end


to ageclasses ;; animals age one year each rainy season
  if season? = "rainy" [
   set num-10yom num-9yom
   set num-9yom num-8yom
   set num-8yom num-7yom
   set num-7yom num-6yom
   set num-6yom num-5yom
   set num-5yom num-4yom
   set num-4yom num-3yom
   set num-3yom num-2yom
   set num-2yom num-1yom
   set num-1yom num-0yom
   set num-14yof num-13yof
   set num-13yof num-12yof
   set num-12yof num-11yof
   set num-11yof num-10yof
   set num-10yof num-9yof
   set num-9yof num-8yof
   set num-8yof num-7yof
   set num-7yof num-6yof
   set num-6yof num-5yof
   set num-5yof num-4yof
   set num-4yof num-3yof
   set num-3yof num-2yof
   set num-2yof num-1yof
   set num-1yof num-0yof
   set num-0yom 0
   set num-0yof 0
   ]
  defineherds ;; repeat after each procedure to update the age and sex classes
end


to sellcattle ;; animals are sold in the dry season - offtake rates vary by age and sex and are probabilistic
  if season? = "dry" [
  if num-1yof > 0 [ repeat num-1yof [
        if random-float 1 <= random-normal 0.0008 0.0007
        [set num-1yof num-1yof - 1
         ]]]
  if num-0yof > 0 [ repeat num-0yof [
        if random-float 1 <= random-normal 0.0008 0.0007
        [set num-0yof num-0yof - 1
         ]]]
  if  num-0yom > 0 [ repeat  num-0yom [
        if random-float 1 <= random-normal 0.0026 0.002
        [set  num-0yom  num-0yom - 1
         ]]]
  if num-1yom > 0 [ repeat num-1yom [
        if random-float 1 <= random-normal 0.0026 0.002
        [set num-1yom num-1yom - 1
         ]]]
  if num-2yof > 0 [repeat num-2yof [
        if random-float 1 <= random-normal 0.021 0.019
        [set num-2yof num-2yof - 1
         ]]]
  if num-3yof > 0 [repeat num-3yof [
        if random-float 1 <= random-normal 0.021 0.019
        [set num-3yof num-3yof - 1
         ]]]
  if num-2yom > 0 [repeat num-2yom [
        if random-float 1 <= random-normal 0.028 0.012
        [set num-2yom num-2yom - 1
         ]]]
  if num-3yom > 0 [repeat num-3yom [
        if random-float 1 <= random-normal 0.028 0.012
        [set num-3yom num-3yom - 1
         ]]]
  if num-4yof > 0 [repeat num-4yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-4yof num-4yof - 1
         ]]]
  if num-5yof > 0 [repeat num-5yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-5yof num-5yof - 1
         ]]]
  if num-6yof > 0 [repeat num-6yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-6yof num-6yof - 1
         ]]]
  if num-7yof > 0 [repeat num-7yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-7yof num-7yof - 1
         ]]]
  if num-8yof > 0 [repeat num-8yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-8yof num-8yof - 1
          ]]]
  if num-9yof > 0 [repeat num-9yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-9yof num-9yof - 1
         ]]]
  if num-10yof > 0 [repeat num-10yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-10yof num-10yof - 1
         ]]]
  if num-11yof > 0 [repeat num-11yof [
        if random-float 1 <= random-gamma 0.0085 0.008
        [set num-11yof num-11yof - 1
         ]]]
  if num-4yom > 0 [repeat num-4yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-4yom num-4yom - 1
         ]]]
  if num-5yom > 0 [repeat num-5yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-5yom num-5yom - 1
         ]]]
  if num-6yom > 0 [repeat num-6yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-6yom num-6yom - 1
         ]]]
  if num-7yom > 0 [repeat num-7yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-7yom num-7yom - 1
         ]]]
  if num-8yom > 0 [repeat num-8yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-8yom num-8yom - 1
         ]]]
  if num-9yom > 0 [repeat num-9yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-9yom num-9yom - 1
         ]]]
  if num-10yom > 0 [repeat num-10yom [
        if random-float 1 <= random-gamma 0.011 0.004
        [set num-bull num-bull - 1
         ]]]
  if num-12yof > 0 [repeat num-12yof [
        if random-float 1 <= random-normal 0.0049 0.002
        [set num-12yof num-12yof - 1
         ]]]
  if num-13yof > 0 [repeat num-13yof [
        if random-float 1 <= random-normal 0.0049 0.002
        [set num-13yof num-13yof - 1
         ]]]
  if num-14yof > 0 [repeat num-14yof [
        if random-float 1 <= random-normal 0.0049 0.002
        [set num-14yof num-14yof - 1
         ]]]
  ]
  defineherds  ;; repeat after each procedure to update the age and sex classes
end


to mortcattle ;; animals die in the dry season - mortality rates vary by age and sex and are probabilistic
  if season? = "dry" [
      if num-1yof > 0 [ repeat num-1yof [
        if random-float 1 <= random-normal .2196 .093
        [set num-1yof num-1yof - 1]]]
      if num-0yof > 0 [ repeat num-0yof [
        if random-float 1 <= random-normal .2196 .093
        [set num-0yof num-0yof - 1]]]
      if num-0yom > 0 [ repeat  num-0yom [
        if random-float 1 <= random-normal .2196 .093
        [set  num-0yom  num-0yom - 1]]]
      if num-1yom > 0 [ repeat num-1yom [
        if random-float 1 <= random-normal .2196 .093
        [set num-1yom num-1yom - 1]]]
      if num-2yof > 0 [repeat num-2yof [
        if random-float 1 <= random-normal .0606 .0146
        [set num-2yof num-2yof - 1]]]
      if num-3yof > 0 [repeat num-3yof [
        if random-float 1 <= random-normal .0606 .0146
        [set num-3yof num-3yof - 1]]]
      if num-2yom > 0 [repeat num-2yom [
        if random-float 1 <= random-normal .0606 .0146
        [set num-2yom num-2yom - 1]]]
      if num-3yom > 0 [repeat num-3yom [
        if random-float 1 <= random-normal .0606 .0146
        [set num-3yom num-3yom - 1]]]
      if num-4yof > 0 [repeat num-4yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-4yof num-4yof - 1]]]
      if num-5yof > 0 [repeat num-5yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-5yof num-5yof - 1]]]
      if num-6yof > 0 [repeat num-6yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-6yof num-6yof - 1]]]
      if num-7yof > 0 [repeat num-7yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-7yof num-7yof - 1]]]
      if num-8yof > 0 [repeat num-8yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-8yof num-8yof - 1]]]
      if num-9yof > 0 [repeat num-9yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-9yof num-9yof - 1]]]
      if num-10yof > 0 [repeat num-10yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-10yof num-10yof - 1]]]
      if num-11yof > 0 [repeat num-11yof [
        if random-float 1 <= random-normal .0572 .0346
        [set num-11yof num-11yof - 1]]]
      if num-4yom > 0 [repeat num-4yom [
        if random-float 1 <= random-normal .0572 .0146
        [set num-4yom num-4yom - 1]]]
      if num-5yom > 0 [repeat num-5yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-5yom num-5yom - 1]]]
      if num-6yom > 0 [repeat num-6yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-6yom num-6yom - 1]]]
      if num-7yom > 0 [repeat num-7yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-7yom num-7yom - 1]]]
      if num-8yom > 0 [repeat num-8yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-8yom num-8yom - 1]]]
      if num-9yom > 0 [repeat num-9yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-9yom num-9yom - 1]]]
      if num-10yom > 0 [repeat num-10yom [
        if random-float 1 <= random-normal .0572 .0346
        [set num-bull num-bull - 1]]]
      if num-12yof > 0 [repeat num-12yof [
        if random-float 1 <= random-normal .695 0
        [set num-12yof num-12yof - 1]]]
      if num-13yof > 0 [repeat num-13yof [
        if random-float 1 <= random-normal .695 0
        [set num-13yof num-13yof - 1]]]
      if num-14yof > 0 [repeat num-14yof [
        if random-float 1 <= random-normal .695 0
        [set num-14yof num-14yof - 1]]]
      ]
  defineherds  ;; repeat after each procedure to update the age and sex classes
end


to reproducecattle ;; cows reproduce - the rate is probabilistic
  if season? =  "rainy" [
  repeat num-cow [
  if random-float 1 <= .7 [  ;; each cow has a seventy percent chance of reproducing each year
  ifelse random-float 1 <= .5  ;; equal opportunity to produce male or female calf
    [set num-0yom num-0yom + 1]
    [set num-0yof num-0yof + 1]
    ]]]
  defineherds  ;; repeat after each procedure to update the age and sex classes
end


to globalcount ;; this updates the number of animals in the herd by age and sex class in the interface.
  set global-num-cow 0
  set global-num-bull 0
  set global-num-heifer 0
  set global-num-bullock 0
  set global-num-calf 0
  set global-num-mcalf 0
  set global-num-elderlycow 0
  ask herds [
    set global-num-cow global-num-cow + num-cow
    set global-num-bull global-num-bull + num-bull
    set global-num-heifer global-num-heifer + num-heifer
    set global-num-bullock global-num-bullock + num-bullock
    set global-num-calf global-num-calf + num-calf
    set global-num-mcalf global-num-mcalf + num-mcalf
    set global-num-elderlycow global-num-elderlycow + num-elderlycow
    set global-num-whole-herd global-num-cow + global-num-bull + global-num-heifer + global-num-bullock + global-num-calf + global-num-mcalf + global-num-elderlycow
    ]
end
@#$#@#$#@
GRAPHICS-WINDOW
17
557
262
678
1
1
30.0
1
10
1
1
1
0
1
1
1
-1
1
-1
1
0
0
0
ticks
30.0

BUTTON
13
57
76
90
setup
setup
NIL
1
T
OBSERVER
NIL
S
NIL
NIL
1

BUTTON
82
57
145
90
go
go
T
1
T
OBSERVER
NIL
Z
NIL
NIL
1

BUTTON
12
102
146
135
Go 50/100/500
go\nif ticks = 50  [stop]\nif ticks = 100 [stop]\nif ticks = 500 [stop]\n
T
1
T
OBSERVER
NIL
G
NIL
NIL
1

PLOT
170
347
812
685
Herd Growth Rate Year to Year
NIL
NIL
0.0
0.0
0.0
0.0
true
true
"" ""
PENS
"average growth rate (%)" 1.0 0 -5298144 true "" "plot (thisyear / lastyear)"
"change in number of animals" 1.0 0 -6565750 true "" "plot (thisyear - lastyear)"

MONITOR
15
500
134
545
current herd size
endingpop
0
1
11

MONITOR
15
452
136
497
starting herd size
startingpop
17
1
11

MONITOR
656
20
714
65
season?
season?
17
1
11

SLIDER
13
17
148
50
initial-herd-size
initial-herd-size
1
300
100
1
1
NIL
HORIZONTAL

SWITCH
11
144
145
177
Offtake
Offtake
0
1
-1000

PLOT
172
17
641
337
Number of animals in the herd
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot thisyear"

MONITOR
658
125
760
170
herd growth (%)
growthlistaverage
2
1
11

TEXTBOX
22
197
136
215
HERD COMPOSITION
11
0.0
1

MONITOR
657
70
714
115
Year
ticks / 2
0
1
11

TEXTBOX
44
427
110
445
HERD SIZE
11
0.0
1

MONITOR
11
219
74
264
calves
global-num-calf / global-num-whole-herd
2
1
11

MONITOR
85
218
148
263
mcalves
global-num-mcalf / global-num-whole-herd
2
1
11

MONITOR
11
271
75
316
heifers
global-num-heifer / global-num-whole-herd
2
1
11

MONITOR
86
270
151
315
bullocks
global-num-bullock / global-num-whole-herd
2
1
11

MONITOR
13
322
77
367
cows
global-num-cow / global-num-whole-herd
2
1
11

MONITOR
86
322
153
367
bulls
global-num-bull / global-num-whole-herd
2
1
11

MONITOR
13
373
79
418
old cows
global-num-elderlycow / global-num-whole-herd
2
1
11

@#$#@#$#@
## Model Description

The Agent-Based Model (ABM) that we developed to examine the dynamics of herd growth is part of a larger study that examines the coupled dynamics of herds and household demography in African pastoral systems. ABMs are commonly used tools to examine the dynamics of complex systems, but they can also be used to simulate demographic dynamics in which stochasticity plays an important role. We used the model to examine the role of scale (herd size) stochasticity (in mortality and fertility) on herd growth in African pastoral systems.

We built the model in NetLogo (version 5.05) (Wilensky 1999) and will publish the model at OpenABM (www.openabm.org)(Janssen et al. 2008). We have requested that our model be certified by the Network for Computational Modeling in the Social and Ecological Sciences (CoMSES Net)(Rollins et al. 2014). The model description follows the ODD (Overview, Design concepts, Details) protocol (Grimm et al. 2006, Grimm et al. 2010) to provide a clear and comprehensive description of our model below.

In designing our ABM we used a strategy called pattern-oriented modeling (POM) in which the goal is to use multiple patterns observed in pastoral systems to guide the design of the model (Grimm et al. 2005). We derived the mortality, fertility, and offtake rates from a review of the literature (notably, Dahl and Hjort 1976; Wagenaar, Diallo, and Sayers 1986; Sutter 1987). Our model is relatively simple but captures the key dynamics of the family herds in African pastoral systems in which herds consists of animals in different age and sex classes (e.g., calves, heifers, bullocks, cows, bulls) that each have different mortality and offtake rates. The model is non-spatial – we model only the herd and not the environment – and there are thus no density-dependent feedbacks.

## Purpose

This model was designed to examine the dynamics of cattle herds in African pastoral systems, in particular to examine the role of scale (number of animals in a herd) and stochasticity (in mortality and fertility rates) on herd growth in African pastoral systems. The hypothesis is that herd size may increase and decrease due stochasticity in mortality and fertility rates and that when herd size is below a certain threshold there is a higher risk that the herd will “die” or cease to exists. The effect of stochasticity does not threaten herds that are above the herd-size threshold.

## Entities, state variables and scales

The model has only one entity: a family herd of cattle. The herd consists of animals in different age and sex classes (e.g., calves, heifers, bullocks, cows, bulls) that have different mortality and offtake rates. The model is non-spatial – we model only the herd and not the environment – and there are thus no density-dependent feedbacks. The time steps in the model are six-month seasons – rainy and dry – that make up one year.

## Process overview and scheduling

The simulation starts in the rainy season. In the rainy season animals increase one-year in age and cows have a chance to reproduce. In the dry season animals have chance to die or be sold. Animals in different age and sex classes (e.g., calves, heifers, bullocks, cows, bulls) have different probabilities of dying and being sold. These probabilities have been derived from our literature review.

## Design Concepts

The basic principle or question of this model is that stochasticity in fertility, mortality, and offtake rates and economies of scale (herd size threshold) can lead to different outcomes in terms of herd size and composition. The emergent property is herd size and composition. The objective of herds is to grow in size. Stochasticity and scale (herd size) are critical components of the model as they shape the emergent properties of herd size and composition. There is no adaptation, learning, prediction, collectives or interaction in the model. In the simulations we can conduct observations of the following data: herd size, herd composition, and growth rate.

## Initialization

The size of the herd can be set at the start of each simulation. The composition of the herd – number of animals in each of the age and sex classes – is randomized but follows a distribution that de derived from our literature review. The mortality, fertility, and offtake rates are probabilistic and also derived from our review.

## Input data

We used data derived from an extensive literature review to derive parameters for herd composition, mortality rates, fertility rates, and offtake rates (notably, Dahl and Hjort 1976; Wagenaar, Diallo, and Sayers 1986; Sutter 1987).

## Submodels

There are four submodels. The first one increases the age of all the animals in the rainy season. The second one gives cows a chance to reproduce in the rainy season. In the third one animals have a chance to be sold and in the fourth one animals have chance to die. After each submodel, the herd composition – the number of animals in the different age and sex classes – is updated.

## References Cited


Dahl, Gudrun, and Anders Hjort. 1976. Having herds: pastoral herd growth and household economy, Stockholm Studies in Social Anthropology. Stockholm (Sweden): Department of Social Anthropology, University of Stockholm.

Grimm, Volker, Uta Berger, Finn Bastiansen, Sigrunn Eliassen, Vincent Ginot, Jarl Giske, John Goss-Custard, Tamara Grand, Simone K. Heinz, and Geir Huse. 2006. A standard protocol for describing individual-based and agent-based models. Ecological Modelling 198 (1-2):115-126.

Grimm, Volker, Uta Berger, Donald L. DeAngelis, J. Gary Polhill, Jarl Giske, and Steven F. Railsback. 2010. The ODD protocol: A review and first update. Ecological Modelling 221 (23):2760-2768.

Grimm, Volker, Eloy Revilla, Uta Berger, Florian Jeltsch, Wolf M. Mooij, Steven F. Railback, Hans-Hermann Thulke, Jacob Weiner, Thorsten Wiegand, and Donald L. DeAngelis. 2005. Pattern-oriented modeling of agent-based complex systems: lessons from ecology. Science 310 (11 November 2005):987-991.

Janssen, Marco A., Lilian Na'ia Alessa, Michael Barton, Sean Bergin, and Allen Lee. 2008. Towards a Community Framework for Agent-Based Modelling. Journal of Artificial Societies and Social Simulation 11 (2):6.

Rollins, Nathan D., C. Michael Barton, Sean Bergin, Marco A. Janssen, and Allen Lee. 2014. A Computational Model Library for publishing model documentation and code. Environmental Modelling & Software 61:59-64.

Sutter, John W. 1987. Cattle and inequality: herd size differences and pastoral production among the Fulani of northeastern Senegal. Africa 57 (2):196-218.

Wagenaar, K. T., A. Diallo, and A. R. Sayers. 1986. Productivity of transhumant Fulani cattle in the inner Niger delta of Mali, ILCA research report ; no. 13. Addis Ababa, Ethiopia: International Livestock Centre for Africa.

NetLogo. Center for Connected Learning and Computer−Based Modeling, Northwestern University, Evanston (IL).

@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks = 200</exitCondition>
    <metric>global-num-cow</metric>
    <metric>endingpop</metric>
    <enumeratedValueSet variable="oldcowofftake">
      <value value="0.0049"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="cowofftake">
      <value value="0.0085"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mcalfofftake">
      <value value="0.0026"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="calfofftake">
      <value value="8.0E-4"/>
    </enumeratedValueSet>
    <steppedValueSet variable="initial-herd-size" first="5" step="5" last="150"/>
    <enumeratedValueSet variable="heiferofftake">
      <value value="0.021"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Grow-Older">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bullofftake">
      <value value="0.011"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Mortality">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bullockofftake">
      <value value="0.028"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Offtake">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Reproduction">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
